@@ -1,4 +1,5 @@
-/* Copyright (C) 2007-2017  B.A.T.M.A.N. contributors:
+/* SPDX-License-Identifier: GPL-2.0 */
+/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
  *
  * Marek Lindner, Simon Wunderlich
  *
@@ -21,6 +22,8 @@
 #ifndef _NET_BATMAN_ADV_COMPAT_H_
 #define _NET_BATMAN_ADV_COMPAT_H_
 
+#ifdef __KERNEL__
+
 #include <linux/version.h>	/* LINUX_VERSION_CODE */
 #include <linux/kconfig.h>
 #include <generated/autoconf.h>
@@ -159,4 +162,6 @@ static int __batadv_interface_kill_vid(struct net_device *dev, __be16 proto,\
 
 #endif /* < KERNEL_VERSION(4, 15, 0) */
 
+#endif /* __KERNEL__ */
+
 #endif /* _NET_BATMAN_ADV_COMPAT_H_ */
